==> pf4-component-mapper-3.16.0.tgz: package/esm/radio/radio.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["value", "label"],
    _excluded2 = ["name", "type"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import { Radio as Pf4Radio } from "@patternfly/react-core/dist/esm/components/Radio/Radio.js";
import FormGroup from '../form-group/form-group';

var RadioOption = function RadioOption(_ref) {
  var name = _ref.name,
      _ref$option = _ref.option,
      value = _ref$option.value,
      label = _ref$option.label,
      restOption = _objectWithoutProperties(_ref$option, _excluded),
      isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly;

  var _useFieldApi = useFieldApi({
    name: name,
    value: value
  }),
      input = _useFieldApi.input;

  return /*#__PURE__*/React.createElement(Pf4Radio, _extends({
    key: "".concat(name, "-").concat(value)
  }, input, {
    isChecked: input.value === value,
    value: value,
    onChange: function onChange() {
      return input.onChange(value);
    },
    label: label,
    id: "".concat(name, "-").concat(value),
    "aria-label": label,
    isDisabled: isDisabled || isReadOnly
  }, restOption));
};

RadioOption.propTypes = {
  name: PropTypes.string.isRequired,
  option: PropTypes.shape({
    label: PropTypes.node.isRequired,
    value: PropTypes.any.isRequired
  }).isRequired,
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  radioGroupValue: PropTypes.any
};

var Radio = function Radio(_ref2) {
  var name = _ref2.name,
      type = _ref2.type,
      props = _objectWithoutProperties(_ref2, _excluded2);

  /**
   * You cannot assign type radio to PF4 radio buttons input. It will break and will not set input value, only checked property
   * It has to be reqular input and we have change the radio value manully to the option value
   */
  var _useFieldApi2 = useFieldApi(_objectSpread({
    name: name
  }, props)),
      label = _useFieldApi2.label,
      isRequired = _useFieldApi2.isRequired,
      helperText = _useFieldApi2.helperText,
      meta = _useFieldApi2.meta,
      validateOnMount = _useFieldApi2.validateOnMount,
      description = _useFieldApi2.description,
      hideLabel = _useFieldApi2.hideLabel,
      input = _useFieldApi2.input,
      isReadOnly = _useFieldApi2.isReadOnly,
      isDisabled = _useFieldApi2.isDisabled,
      id = _useFieldApi2.id,
      FormGroupProps = _useFieldApi2.FormGroupProps,
      options = _useFieldApi2.options;

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioOption, {
      key: option.value,
      name: name,
      option: option,
      isReadOnly: isReadOnly,
      isDisabled: isDisabled
    });
  }));
};

Radio.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  name: PropTypes.string.isRequired,
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.any
  })).isRequired,
  type: PropTypes.any,
  FormGroupProps: PropTypes.object
};
export default Radio;

==> pf4-component-mapper-3.19.0.tgz: package/esm/radio/radio.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["value", "label"],
    _excluded2 = ["name", "type"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import { Radio as Pf4Radio } from "@patternfly/react-core/dist/esm/components/Radio/Radio.js";
import FormGroup from '../form-group/form-group';

var RadioOption = function RadioOption(_ref) {
  var name = _ref.name,
      _ref$option = _ref.option,
      value = _ref$option.value,
      label = _ref$option.label,
      restOption = _objectWithoutProperties(_ref$option, _excluded),
      isDisabled = _ref.isDisabled,
      isReadOnly = _ref.isReadOnly;

  var _useFieldApi = useFieldApi({
    name: name,
    value: value
  }),
      input = _useFieldApi.input;

  return /*#__PURE__*/React.createElement(Pf4Radio, _extends({
    key: "".concat(name, "-").concat(value)
  }, input, {
    isChecked: input.value === value,
    value: value,
    onChange: function onChange() {
      return input.onChange(value);
    },
    label: label,
    id: "".concat(name, "-").concat(value),
    "aria-label": label,
    isDisabled: isDisabled || isReadOnly
  }, restOption));
};

RadioOption.propTypes = {
  name: PropTypes.string.isRequired,
  option: PropTypes.shape({
    label: PropTypes.node.isRequired,
    value: PropTypes.any.isRequired
  }).isRequired,
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  radioGroupValue: PropTypes.any
};

var Radio = function Radio(_ref2) {
  var name = _ref2.name,
      type = _ref2.type,
      props = _objectWithoutProperties(_ref2, _excluded2);

  /**
   * You cannot assign type radio to PF4 radio buttons input. It will break and will not set input value, only checked property
   * It has to be reqular input and we have change the radio value manully to the option value
   */
  var _useFieldApi2 = useFieldApi(_objectSpread({
    name: name
  }, props)),
      label = _useFieldApi2.label,
      isRequired = _useFieldApi2.isRequired,
      helperText = _useFieldApi2.helperText,
      meta = _useFieldApi2.meta,
      validateOnMount = _useFieldApi2.validateOnMount,
      description = _useFieldApi2.description,
      hideLabel = _useFieldApi2.hideLabel,
      input = _useFieldApi2.input,
      isReadOnly = _useFieldApi2.isReadOnly,
      isDisabled = _useFieldApi2.isDisabled,
      id = _useFieldApi2.id,
      FormGroupProps = _useFieldApi2.FormGroupProps,
      options = _useFieldApi2.options;

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, options.map(function (option) {
    return /*#__PURE__*/React.createElement(RadioOption, {
      key: option.value,
      name: name,
      option: option,
      isReadOnly: isReadOnly,
      isDisabled: isDisabled
    });
  }));
};

Radio.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  name: PropTypes.string.isRequired,
  options: PropTypes.arrayOf(PropTypes.shape({
    label: PropTypes.node,
    value: PropTypes.any
  })).isRequired,
  type: PropTypes.any,
  FormGroupProps: PropTypes.object
};
export default Radio;
